"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Accounts = void 0;
const baseResource_1 = require("./baseResource");
class Accounts extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/accounts", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async closeAccount(request) {
        return this.httpPost(`/${request.accountId}/close`, { data: request.data });
    }
    async reopenAccount(accountId) {
        return this.httpPost(`/${accountId}/reopen`);
    }
    async freezeAccount(request) {
        return this.httpPost(`/${request.accountId}/freeze`, { data: request.data });
    }
    async unfreezeAccount(accountId) {
        return this.httpPost(`/${accountId}/unfreeze`);
    }
    /**
     * Include is Optional. Related resource available to include: customer. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources)
     * @param accountId
     * @param include
     */
    async get(accountId, include = "") {
        return this.httpGet(`/${accountId}`, { params: { include } });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": this.customStringify(params.tags, ":") }),
            ...((params === null || params === void 0 ? void 0 : params.include) && { "include": params.include }),
            ...((params === null || params === void 0 ? void 0 : params.fromBalance) && { "filter[fromBalance]": params.fromBalance }),
            ...((params === null || params === void 0 ? void 0 : params.toBalance) && { "filter[toBalance]": params.toBalance }),
            ...((params === null || params === void 0 ? void 0 : params.type) && { "filter[type]": params.type })
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
    async update(request) {
        return this.httpPatch(`/${request.accountId}`, { data: request.data });
    }
    async limits(accountId) {
        return this.httpGet(`/${accountId}/limits`);
    }
    async getAvailableDepositProducts(accountId) {
        return this.httpGet(`/${accountId}/deposit-products`);
    }
    async addOwners(request) {
        return this.httpPost(`/${request.accountId}/relationships/customers`, { data: request.data });
    }
    async removeOwners(request) {
        return this.httpDelete(`/${request.accountId}/relationships/customers`, { data: request.data });
    }
    async enterDaca(accountId) {
        return this.httpGet(`/${accountId}/enter-daca`);
    }
    async activateDaca(accountId) {
        return this.httpGet(`/${accountId}/activate-daca`);
    }
    async deactivateDaca(accountId) {
        return this.httpGet(`/${accountId}/deactivate-daca`);
    }
    async getRepaymentInformation(accountId) {
        return this.httpGet(`/${accountId}/repayment-information`);
    }
}
exports.Accounts = Accounts;
